import json.decoder
import requests
import json


class MatomoClient(object):
    """
        Provide an entry point into the matomo api.
    """

    def __init__(
            self,
            api_key,
            base_url,
    ) -> None:
        self.base_url = base_url

    def make_request(self, params) -> json:
        """Perform the request to the Matomo api and return the
        json report

        Accepts:
            Params: Dict containing
                module, method, idSite, token_auth, depth,
                date, period, format, expanded and flat keys.
                Example:
                    params = dict(
                        module='API',
                        method='Actions.getPageUrls',   # Configurable
                        idSite=site_id,                 # Configurable
                        token_auth=token,               # Configurable
                        depth=5,                        # Configurable
                        date=search_date,               # Configurable
                        period='day',
                        format='JSON',
                        expanded=1,
                        flat=1,
                     )

        Raises:
            ValueError: _description_

        Returns:
            json: JSON representation of the report
        """
        url = f"{self.base_url}"

        try:
            res = requests.get(url, params)
            if res.status_code != 200:
                raise ValueError
            data = res.json()
            res.close()
            return data
        except (
            KeyError,
            TypeError,
            ValueError,
            json.decoder.JSONDecodeError,
            requests.exceptions.RequestException,
        ):
            raise ValueError(res.content)
